Type: Package
Package: rtweet
Title: Collecting Twitter Data
Version: 2.0.0
Authors@R: c(
    person("Michael W.", "Kearney", , "kearneymw@missouri.edu", role = "aut",
           comment = c(ORCID = "0000-0002-0730-4694")),
    person("Lluís", "Revilla Sancho", , "lluis.revilla@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-9747-2570")),
    person("Hadley", "Wickham", role = "aut",
           comment = c(ORCID = "0000-0003-4757-117X")),
    person("Andrew", "Heiss", role = "rev",
           comment = c(ORCID = "0000-0002-3948-3914")),
    person("Francois", "Briatte", role = "rev"),
    person("Jonathan", "Sidi", , "yonicd@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0002-4222-1819"))
  )
Description: An implementation of calls designed to collect and organize
    Twitter data via Twitter's REST and stream Application Program
    Interfaces (API), which can be found at the following URL:
    <https://developer.twitter.com/en/docs>.
License: MIT + file LICENSE
URL: https://docs.ropensci.org/rtweet/,
        https://github.com/ropensci/rtweet/
BugReports: https://github.com/ropensci/rtweet/issues
Depends: R (>= 4.0.0)
Imports: bit64 (>= 4.0.5), curl (>= 4.3.2), httr (>= 1.3.0), httr2 (>=
        1.0.0), jsonlite (>= 0.9.22), lifecycle (>= 1.0.0), methods,
        progress (>= 1.2.2), rlang (>= 0.4.10), tibble (>= 1.3.4),
        tools, utils, withr (>= 2.5.0)
Suggests: askpass (>= 1.1), covr (>= 3.5.1), dplyr (>= 1.0.9), ggplot2
        (>= 3.3.5), httpuv (>= 1.6.5), igraph (>= 1.3.2), knitr (>=
        1.39), magick (>= 2.7.3), maps (>= 3.4.0), openssl (>= 2.0.2),
        rmarkdown (>= 2.14), spelling (>= 2.2.1), testthat (>= 3.1.0),
        vcr (>= 0.6.0), webshot (>= 0.5.3)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.0
Language: en-US
NeedsCompilation: no
Packaged: 2024-02-24 15:10:58 UTC; lluis
Author: Michael W. Kearney [aut] (<https://orcid.org/0000-0002-0730-4694>),
  Lluís Revilla Sancho [aut, cre]
    (<https://orcid.org/0000-0001-9747-2570>),
  Hadley Wickham [aut] (<https://orcid.org/0000-0003-4757-117X>),
  Andrew Heiss [rev] (<https://orcid.org/0000-0002-3948-3914>),
  Francois Briatte [rev],
  Jonathan Sidi [ctb] (<https://orcid.org/0000-0002-4222-1819>)
Maintainer: Lluís Revilla Sancho <lluis.revilla@gmail.com>
Repository: CRAN
Date/Publication: 2024-02-24 16:20:02 UTC
