<!-- This is an issue template for bugs and requests for R pkg rtweet -->

<!-- If you've encountered a likely bug in rtweet, please take a few seconds to 
look through existing issues for a similar issue. If you don't see a related 
issue, please complete the prompts below to make it easier to replicate and 
[hopefully] resolve your issue.  -->

<!-- If you have some question about how to use this package, please post it on
https://discuss.ropensci.org/tag/rtweet -->

### Problem

<!-- Succinctly describe the problem (be as specific as you think necessary) -->

### Expected behavior

<!-- Describe the behavior/result you expected -->

### Reproduce the problem

<!-- Describe and provide relevant code to reproduce the problem -->
<!-- If code doesn't always produce error, provide approximate code anyway -->

``` r
## insert code here

```

### rtweet version

<!-- run the code below and copy/paste the output -->

``` r
## copy/paste output
packageVersion("rtweet")
```


### Session info

<!-- run the code below and copy/paste the output -->

``` r
## copy/paste output
sessionInfo()
```

<!-- If you think the problem may be related to features/limitations of 
Twitter's API, you can find more information about Twitter's APIs here: 
https://developer.twitter.com/en/docs.html -->

<!-- Thank you for using and improving rtweet!  -->
