## revdepcheck results

We checked 13 reverse dependencies (3 from CRAN + 10 from Bioconductor), comparing R CMD check results across CRAN and dev versions of this package.

 * We saw 0 new problems
 * We failed to check 0 packages

